==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/hu/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'A tömeges törlési eszközök megerősítése',
  'bulk_delete_help'	=> 'Tömeges törléshez tekintse át az eszközöket. Ha törli az eszközöket, azok visszaállíthatók, de többé nem lesznek hozzárendelve a korábban hozzárendelt felhasználókhoz.',
  'bulk_delete_warn'	=> 'Le akarod törölni a :asset_count eszközt.',
	'bulk_update'		=> 'Tömeges eszköz frissítés',
	'bulk_update_help'	=> 'Ez az űrlap segít frissíteni több eszközt egyszerre. Csak töltsd ki a változtatni kívánt mezőket. Mindent amit üresen hagysz az változatlan marad. ',
	'bulk_update_warn'	=> 'Meg akarod módosítani a(z) :asset_count eszköz tulajdonságait.',
    'checkedout_to'		=> 'Kiadva',
    'checkout_date'		=> 'Kiadási dátum',
    'checkin_date'		=> 'Visszavétel dátuma',
    'checkout_to'		=> 'Kiadva',
    'cost'				=> 'Beszerzési érték',
    'create'			=> 'Eszköz létrehozása',
    'date'				=> 'Vásárlás dátuma',
    'depreciation'	    => 'Értékcsökkenés',
    'depreciates_on'	=> 'Leértékelődik',
    'default_location'	=> 'Alapértelmezett hely',
    'eol_date'			=> 'Lejárat Dátuma',
    'eol_rate'			=> 'EOL arány',
    'expected_checkin'  => 'Várható visszaadás dátuma',
    'expires'			=> 'Lejárat',
    'fully_depreciated'	=> 'Teljesen értékcsökkentett',
    'help_checkout'		=> 'Ha azonnal kiadná ezt az eszközt, válassza a "Kiadásra készen" státuszt a fenti listából. ',
    'mac_address'		=> 'MAC-cím',
    'manufacturer'		=> 'Gyártó',
    'model'				=> 'Modell',
    'months'			=> 'hónapok',
    'name'				=> 'Eszköz neve',
    'notes'				=> 'Megjegyzések',
    'order'				=> 'Számla sorszáma',
    'qr'				=> 'QR Code',
    'requestable'		=> 'A felhasználók kérhetik ezt az eszközt',
    'select_statustype'	=> 'Állapot típusának kiválasztása',
    'serial'			=> 'Sorozatszám',
    'status'			=> 'Státusz',
    'tag'				=> 'Eszköz azonosító',
    'update'			=> 'Eszköz frissítés',
    'warranty'			=> 'Garancia',
		'warranty_expires'		=> 'Jótállás érvényessége',
    'years'				=> 'évek',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/hu/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'A tömeges törlési eszközök megerősítése',
  'bulk_delete_help'	=> 'Tömeges törléshez tekintse át az eszközöket. Ha törli az eszközöket, azok visszaállíthatók, de többé nem lesznek hozzárendelve a korábban hozzárendelt felhasználókhoz.',
  'bulk_delete_warn'	=> 'Le akarod törölni a :asset_count eszközt.',
    'bulk_update'		=> 'Tömeges eszköz frissítés',
    'bulk_update_help'	=> 'Ez az űrlap segít frissíteni több eszközt egyszerre. Csak töltsd ki a változtatni kívánt mezőket. Mindent amit üresen hagysz az változatlan marad. ',
    'bulk_update_warn'	=> 'Meg akarod módosítani a(z) :asset_count eszköz tulajdonságait.',
    'checkedout_to'		=> 'Kiadva',
    'checkout_date'		=> 'Kiadási dátum',
    'checkin_date'		=> 'Visszavétel dátuma',
    'checkout_to'		=> 'Kiadva',
    'cost'				=> 'Beszerzési érték',
    'create'			=> 'Eszköz létrehozása',
    'date'				=> 'Vásárlás dátuma',
    'depreciation'	    => 'Értékcsökkenés',
    'depreciates_on'	=> 'Leértékelődik',
    'default_location'	=> 'Alapértelmezett hely',
    'eol_date'			=> 'Lejárat Dátuma',
    'eol_rate'			=> 'EOL arány',
    'expected_checkin'  => 'Várható visszaadás dátuma',
    'expires'			=> 'Lejárat',
    'fully_depreciated'	=> 'Teljesen értékcsökkentett',
    'help_checkout'		=> 'Ha azonnal kiadná ezt az eszközt, válassza a "Kiadásra készen" státuszt a fenti listából. ',
    'mac_address'		=> 'MAC-cím',
    'manufacturer'		=> 'Gyártó',
    'model'				=> 'Modell',
    'months'			=> 'hónapok',
    'name'				=> 'Eszköz neve',
    'notes'				=> 'Megjegyzések',
    'order'				=> 'Számla sorszáma',
    'qr'				=> 'QR Code',
    'requestable'		=> 'A felhasználók kérhetik ezt az eszközt',
    'select_statustype'	=> 'Állapot típusának kiválasztása',
    'serial'			=> 'Sorozatszám',
    'status'			=> 'Státusz',
    'tag'				=> 'Eszköz azonosító',
    'update'			=> 'Eszköz frissítés',
    'warranty'			=> 'Garancia',
        'warranty_expires'		=> 'Jótállás érvényessége',
    'years'				=> 'évek',
    'asset_location' => 'Eszköz helyszín frissítése',
    'asset_location_update_default_current' => 'Alapértelmezett helyszín és aktuális helyszín frissítése',
    'asset_location_update_default' => 'Csak az alapértelmezett helyszín frissítése',
    'asset_not_deployable' => 'Az eszköz még nem kiadásra kész, még nem kiadható.',
    'asset_deployable' => 'Az eszköz kiadásra kész, kiadható.',
    'processing_spinner' => 'Feldolgozás...',
];
